==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/syncer/leechcraft_syncer_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<context>
    <name>LeechCraft::Plugins::Syncer::Core</name>
    <message>
        <location filename="core.cpp" line="206"/>
        <location filename="core.cpp" line="222"/>
        <source>Sync failure</source>
        <translation>Помилка синхронізації</translation>
    </message>
    <message>
        <location filename="core.cpp" line="207"/>
        <source>Login error when synchronizing plugin %1.</source>
        <translation>Помилка входу при синхронізації плагіну %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="223"/>
        <source>Connection error when synchronizing plugin %1.</source>
        <translation>Помилка з’єднання при синхронізації плагіну %1.</translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="242"/>
        <source>%n item(s) received</source>
        <translation>
            <numerusform>%n елемент отримано</numerusform>
            <numerusform>%n елементи отримано</numerusform>
            <numerusform>%n елементів отримано</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="244"/>
        <source>%n item(s) sent</source>
        <translation>
            <numerusform>%n елемент надісланий</numerusform>
            <numerusform>%n елемента надіслано</numerusform>
            <numerusform>%n елементів надіслано</numerusform>
        </translation>
    </message>
    <message>
        <location filename="core.cpp" line="245"/>
        <source>Sync</source>
        <translation>Синхронізація</translation>
    </message>
    <message>
        <location filename="core.cpp" line="240"/>
        <source>Successfully synchronized plugin %1</source>
        <oldsource>Successfully synchronized plugin %1: %2 items received, %3 items sent.</oldsource>
        <translation>Плагін %1 успішно синхронізовано</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Syncer::Plugin</name>
    <message>
        <location filename="syncer.cpp" line="59"/>
        <source>Synchronization plugin for LeechCraft</source>
        <translation>Плагін синхронізації для LeechCraft</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.65_rc20110125.tar.bz2: leechcraft-0.4.65_rc20110125/src/plugins/syncer/leechcraft_syncer_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<context>
    <name>LeechCraft::Plugins::Syncer::Core</name>
    <message>
        <location filename="core.cpp" line="206"/>
        <location filename="core.cpp" line="222"/>
        <source>Sync failure</source>
        <translation>Помилка синхронізації</translation>
    </message>
    <message>
        <location filename="core.cpp" line="207"/>
        <source>Login error when synchronizing plugin %1.</source>
        <translation>Помилка входу при синхронізації плагіну %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="223"/>
        <source>Connection error when synchronizing plugin %1.</source>
        <translation>Помилка з’єднання при синхронізації плагіну %1.</translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="242"/>
        <source>%n item(s) received</source>
        <translation>
            <numerusform>%n елемент отримано</numerusform>
            <numerusform>%n елементи отримано</numerusform>
            <numerusform>%n елементів отримано</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="core.cpp" line="244"/>
        <source>%n item(s) sent</source>
        <translation>
            <numerusform>%n елемент надісланий</numerusform>
            <numerusform>%n елемента надіслано</numerusform>
            <numerusform>%n елементів надіслано</numerusform>
        </translation>
    </message>
    <message>
        <location filename="core.cpp" line="245"/>
        <source>Sync</source>
        <translation>Синхронізація</translation>
    </message>
    <message>
        <location filename="core.cpp" line="240"/>
        <source>Successfully synchronized plugin %1</source>
        <oldsource>Successfully synchronized plugin %1: %2 items received, %3 items sent.</oldsource>
        <translation>Плагін %1 успішно синхронізовано</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Syncer::Plugin</name>
    <message>
        <location filename="syncer.cpp" line="69"/>
        <source>Synchronization plugin for LeechCraft</source>
        <translation>Плагін синхронізації для LeechCraft</translation>
    </message>
</context>
<context>
    <name>syncersettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <location filename="dummy.cpp" line="3"/>
        <source>Sync settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Login:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="7"/>
        <source>Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="8"/>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="9"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
